@@ -7,7 +7,7 @@
  *
  * GNOME Sudoku is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * GNOME Sudoku is distributed in the hope that it will be useful,
@@ -41,17 +41,6 @@ int* qqwing_generate_puzzle(int difficulty)
     const int BOARD_SIZE = 81;
     SudokuBoard board;
 
-    // Seed RNG exactly once.
-    static GMutex mutex;
-    static bool seeded = false;
-    g_mutex_lock(&mutex);
-    if (!seeded)
-    {
-        srand(time(NULL));
-        seeded = true;
-    }
-    g_mutex_unlock(&mutex);
-
     board.setRecordHistory(true);
     board.setLogHistory(false);
     board.setPrintStyle(SudokuBoard::ONE_LINE);
